@@ -10,7 +10,7 @@ use warnings;
 use strict;
 
 package POE::Component::Curses;
-our $VERSION = '0.093020';
+our $VERSION = '0.093060';
 
 
 # ABSTRACT: the ( currently only ) loader for Curses::toolkit
@@ -57,6 +57,12 @@ sub spawn {
 			},
 			key_handler => sub {
 				my ($kernel, $heap, $keystroke) = @_[ KERNEL, HEAP, ARG0];
+				use Data::Dumper;
+#				my $k = $keystroke;
+#				while(length $k) {
+#					my $c = substr($k, 0, 1, '');
+#					print STDERR sprintf(" -- A D H O  : [%s] [%d] [%x] [%o]- \n", $c, ord($c), ord($c), ord($c));
+#				}
 				use Curses; # for keyname and unctrl
 				if ($keystroke ne -1) {
 					if ($keystroke lt ' ') {
@@ -182,7 +188,7 @@ POE::Component::Curses - the ( currently only ) loader for Curses::toolkit
 
 =head1 VERSION
 
-version 0.093020
+version 0.093060
 
 =head1 SYNOPSIS
 
